@@ -1,6 +1,5 @@
-/*  ADCD - A Diminutive CD player for GNU/Linux
-    Copyright (C) 2004, 2005, 2006, 2007, 2009, 2010, 2012, 2013, 2014
-    Antonio Diaz Diaz.
+/*  ADCD - A Diminutive CD player for Linux/GNU
+    Copyright (C) 2004-2015 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -49,11 +48,20 @@ CD::~CD() { if ( filedes >= 0 ) ::close( filedes ); }
 
 bool CD::read_status( const bool force )
   {
-  if( !force && ( status == no_disc || status == stopped ) ) return false;
+  if( !force && status != playing ) return false;
   const Status old_status = status;
   const int old_tracks = tracks();
 
-  switch( ioctl( filedes, CDROM_DRIVE_STATUS ) )
+  int drive_status;
+  const int timeout = 15;		// my drive needs 8 seconds
+  for( int i = 0; i < timeout; ++i )
+    {
+    drive_status = ioctl( filedes, CDROM_DRIVE_STATUS );
+    if( !force || drive_status != CDS_DRIVE_NOT_READY || i + 1 >= timeout )
+      break;
+    sleep( 1 );
+    }
+  switch( drive_status )
     {
     case CDS_NO_INFO:
     case CDS_DISC_OK:
@@ -301,8 +309,10 @@ const char * CD::loop_name() const
 void CD::playlist( const std::vector< int > & pl )
   {
   playlist_ = pl;
-  if( pl.empty() ) index_ = 0;
-  else if( index_ >= pl.size() ) index_ = pl.size() - 1;
+  if( status == stopped || playlist_.empty() ) { index_ = 0; return; }
+  for( unsigned i = 0; i < playlist_.size(); ++i )
+    if( playlist_[i] == track_ ) { index_ = i; return; }
+  if( index_ >= playlist_.size() ) index_ = playlist_.size() - 1;
   }
 
 
@@ -331,7 +341,7 @@ const char * CD::status_name() const
     {
     case no_disc: return "No Disc";
     case stopped: return "Stopped";
-    case paused : return "Paused ";
+    case paused : return "Paused";
     case playing: return "Playing";
     default:      return "Unknown";
     }
