@@ -1,6 +1,5 @@
-/*  ADCD - A Diminutive CD player for GNU/Linux
-    Copyright (C) 2004, 2005, 2006, 2007, 2009, 2010, 2012, 2013, 2014
-    Antonio Diaz Diaz.
+/*  ADCD - A Diminutive CD player for Linux/GNU
+    Copyright (C) 2004-2015 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -39,13 +38,13 @@ namespace {
 
 const char * const Program_name = "Adcd";
 const char * const program_name = "adcd";
-const char * const program_year = "2014";
+const char * const program_year = "2015";
 const char * invocation_name = 0;
 
 
 void show_help()
   {
-  std::printf( "%s - A Diminutive CD player for GNU/Linux.\n", Program_name );
+  std::printf( "%s - A Diminutive CD player for Linux/GNU.\n", Program_name );
   std::printf( "If invoked without options enters interactive mode.\n"
                "\nUsage: %s [options] [device]\n", invocation_name );
   std::printf( "\nOptions:\n"
@@ -208,7 +207,9 @@ int main( const int argc, const char * argv[] )
   if( stop ) { cd.stop(); interactive = false; }
   if( play )
     {
-    if( !cd.track( track, true ) ) { show_error( "bad track number." ); return 1; }
+    if( !cd.track( track, true ) )
+      { show_error( cd.tracks() ? "bad track number." : cd.status_name() );
+        return 1; }
     interactive = false;
     }
   if( info ) { cd.show_info(); interactive = false; }
