@@ -1,6 +1,5 @@
-/*  ADCD - A Diminutive CD player for GNU/Linux
-    Copyright (C) 2004, 2005, 2006, 2007, 2009, 2010, 2012, 2013, 2014
-    Antonio Diaz Diaz.
+/*  ADCD - A Diminutive CD player for Linux/GNU
+    Copyright (C) 2004-2015 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -150,7 +149,7 @@ void show_data( const CD & cd )
             s, c, msf.minute(), msf.second(), total.minute(), total.second() );
   if( cd.linear() ) show_playlist( 0 );
   else show_playlist( &cd.playlist(), cd.index() );
-  mvaddstr( 0, 37, cd.status_name() );
+  mvaddstr( 0, 37, cd.status_name() ); wclrtoeol( stdscr );
   wrefresh( stdscr );
   }
 
